CanvasController class

Inheritance

Constructors

CanvasController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform Matrix4
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateTo(Matrix4 target, {Duration duration = const Duration(milliseconds: 350), Curve curve = Curves.easeInOut}) → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
override
flingZoom(double velocity, Offset focalPoint) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pan(Offset delta) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setVsync(TickerProvider vsync) → void
stopAnimation() → void
toString() String
A string representation of this object.
inherited
zoom(double scaleDelta, Offset focalPoint) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

maxScale → const double
minScale → const double