position property
Define the transform by individual components.
All three must be provided if bounds is null.
Implementation
final Offset? position;
Define the transform by individual components.
All three must be provided if bounds is null.
final Offset? position;