RectTransformController class

Inheritance

Constructors

RectTransformController()

Properties

angle double
no setter
bounds Rect
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
position Offset
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Offset
no setter
size Size
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
endResize() → void
move(Offset delta) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
resize(Offset localDelta) → void
rotate(double angleDelta) → void
setTransform(Offset position, double angle, Offset scale, Size size) → void
startResize(Sizer sizer) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited