RectTransformHandles class

Inheritance

Constructors

RectTransformHandles({Key? key, required bool canMove, required bool canRotate, required bool canResize, required double rotatorSize, required double cornerSizerSize, required double strokeHandleSize, required double strokeSize, required double padding, required Color color, dynamic onMove(Offset)?, VoidCallback? onMoveEnd, dynamic onResizeStart(Sizer)?, dynamic onResize(Offset)?, VoidCallback? onResizeEnd, dynamic onRotateStart(DragStartDetails)?, dynamic onRotate(DragUpdateDetails)?, VoidCallback? onRotateEnd})
const

Properties

canMove bool
final
canResize bool
final
canRotate bool
final
color Color
final
cornerSizerSize double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onMove → dynamic Function(Offset)?
final
onMoveEnd VoidCallback?
final
onResize → dynamic Function(Offset)?
final
onResizeEnd VoidCallback?
final
onResizeStart → dynamic Function(Sizer)?
final
onRotate → dynamic Function(DragUpdateDetails)?
final
onRotateEnd VoidCallback?
final
onRotateStart → dynamic Function(DragStartDetails)?
final
padding double
final
rotatorSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeHandleSize double
final
strokeSize double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited