Sizer class sealed
Properties
- alignment → Alignment
-
final
- cursor → SystemMouseCursor
-
final
- growthDirection → Offset
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- insets → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
flipHorizontally(
) → Sizer -
flipVertically(
) → Sizer -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bottom → const BottomSizer
- bottomLeft → const BottomLeftSizer
- bottomRight → const BottomRightSizer
- left → const LeftSizer
- right → const RightSizer
- top → const TopSizer
- topLeft → const TopLeftSizer
- topRight → const TopRightSizer