TopRightSizer class

Inheritance

Constructors

TopRightSizer()
const

Properties

alignment Alignment
finalinherited
cursor SystemMouseCursor
finalinherited
growthDirection Offset
finalinherited
hashCode int
The hash code for this object.
no setterinherited
insets EdgeInsets
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flipHorizontally() Sizer
override
flipVertically() Sizer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited