RectTransform class

Inheritance

Constructors

RectTransform({Key? key, required Widget child, Rect? bounds, Offset? position, double angle = 0, Offset? scale, double worldScale = 1, Size? baseSize, double strokeSize = 0.8, double strokeHandleSize = 4, double cornerSizerSize = 8, double rotatorSize = 16, Color handleColor = Colors.blue, bool canMove = true, bool canRotate = true, bool canResize = true, dynamic onNewTransform(Offset, double, Offset)?, dynamic onNewBounds(Rect, double)?, VoidCallback? onTransformEnd, dynamic onTapInside(PointerDownEvent)?, dynamic onTapOutside(PointerDownEvent)?})
const

Properties

angle double
The rotation angle in radians. Common to both input methods.
final
baseSize Size?
final
bounds Rect?
Define the transform by a bounding box. This is the preferred way if provided.
final
canMove bool
final
canResize bool
final
canRotate bool
final
child Widget
final
cornerSizerSize double
final
handleColor Color
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onNewBounds → dynamic Function(Rect, double)?
final
onNewTransform → dynamic Function(Offset, double, Offset)?
final
onTapInside → dynamic Function(PointerDownEvent)?
final
onTapOutside → dynamic Function(PointerDownEvent)?
final
onTransformEnd VoidCallback?
final
position Offset?
Define the transform by individual components. All three must be provided if bounds is null.
final
rotatorSize double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Offset?
final
strokeHandleSize double
final
strokeSize double
final
worldScale double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RectTransform>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited